@@ -98,8 +98,14 @@ class EmbeddingServiceAsyncClient:
             self.port = config.get("server.port", port or int(os.getenv("EMBEDDING_SERVICE_PORT", "8001")))
             self.timeout = config.get("client.timeout", timeout)
         elif config_dict:
-            self.base_url = config_dict.get("server", {}).get("host", base_url or os.getenv("EMBEDDING_SERVICE_BASE_URL", "http://localhost"))
-            self.port = config_dict.get("server", {}).get("port", port or int(os.getenv("EMBEDDING_SERVICE_PORT", "8001")))
+            server_config = config_dict.get("server", {})
+            # ✅ ИСПРАВЛЕНИЕ: Использовать base_url из конфигурации, если он есть
+            if "base_url" in server_config:
+                self.base_url = server_config["base_url"]
+                self.port = None  # Порт уже включен в base_url
+            else:
+                self.base_url = server_config.get("host", base_url or os.getenv("EMBEDDING_SERVICE_BASE_URL", "http://localhost"))
+                self.port = server_config.get("port", port or int(os.getenv("EMBEDDING_SERVICE_PORT", "8001")))
             self.timeout = config_dict.get("client", {}).get("timeout", timeout)
         else:
             # Use provided parameters or environment variables
@@ -129,10 +135,10 @@ class EmbeddingServiceAsyncClient:
         
         # Validate port
         try:
-            if self.port is None:
-                raise EmbeddingServiceConfigError("port must be provided.")
-            if not isinstance(self.port, int) or self.port <= 0 or self.port > 65535:
-                raise EmbeddingServiceConfigError("port must be a valid integer between 1 and 65535.")
+            # ✅ ИСПРАВЛЕНИЕ: Порт не обязателен, если он уже в base_url
+            if self.port is not None:
+                if not isinstance(self.port, int) or self.port <= 0 or self.port > 65535:
+                    raise EmbeddingServiceConfigError("port must be a valid integer between 1 and 65535.")
         except (ValueError, TypeError) as e:
             raise EmbeddingServiceConfigError(f"Invalid port configuration: {e}") from e
         
@@ -161,7 +167,22 @@ class EmbeddingServiceAsyncClient:
         try:
             url = (base_url or self.base_url).rstrip("/")
             port_val = port if port is not None else self.port
-            return f"{url}:{port_val}{path}"
+            
+            # ✅ ИСПРАВЛЕНИЕ: Проверить, есть ли уже порт в URL
+            if "://" in url:
+                protocol, rest = url.split("://", 1)
+                if ":" in rest:  # Порт уже есть в URL
+                    return f"{url}{path}"
+                elif port_val is not None:  # Порта нет, добавить если есть
+                    return f"{url}:{port_val}{path}"
+                else:  # Порта нет и не указан
+                    return f"{url}{path}"
+            else:
+                # Fallback для URL без протокола
+                if port_val is not None:
+                    return f"{url}:{port_val}{path}"
+                else:
+                    return f"{url}{path}"
         except Exception as e:
             raise EmbeddingServiceConfigError(f"Failed to construct URL: {e}") from e
 
