@@ -79,12 +79,18 @@ class ClientSSLManager:
         try:
             # Create SSL config
             ssl_config_dict = self.config.get("ssl", {})
+            
+            # ✅ ИСПРАВЛЕНИЕ: Учитывать verify: false в mcp_security_framework
+            verify_mode = ssl_config_dict.get("verify_mode", "CERT_REQUIRED")
+            if ssl_config_dict.get("verify", True) == False:
+                verify_mode = "CERT_NONE"
+            
             ssl_config = SSLConfig(
                 enabled=ssl_config_dict.get("enabled", False),
                 cert_file=ssl_config_dict.get("cert_file") if ssl_config_dict.get("cert_file") and os.path.exists(ssl_config_dict.get("cert_file")) else None,
                 key_file=ssl_config_dict.get("key_file") if ssl_config_dict.get("key_file") and os.path.exists(ssl_config_dict.get("key_file")) else None,
                 ca_cert_file=ssl_config_dict.get("ca_cert_file") if ssl_config_dict.get("ca_cert_file") and os.path.exists(ssl_config_dict.get("ca_cert_file")) else None,
-                verify_mode=ssl_config_dict.get("verify_mode", "CERT_REQUIRED"),
+                verify_mode=verify_mode,  # ✅ ИСПРАВЛЕНИЕ: Использовать правильный verify_mode
                 check_hostname=ssl_config_dict.get("check_hostname", True),
                 check_expiry=ssl_config_dict.get("check_expiry", True)
             )
@@ -125,11 +131,16 @@ class ClientSSLManager:
             return None
             
         try:
-            # Force fallback implementation for CERT_NONE mode
+            # ✅ ИСПРАВЛЕНИЕ: Использовать правильный метод SecurityManager
             ssl_config = self.config.get("ssl", {})
-            # ✅ ИСПРАВЛЕНИЕ: Всегда использовать fallback для обхода SecurityManager
-            # SecurityManager.create_client_context() не существует
-            return self._create_client_ssl_context_fallback()
+            
+            # Проверяем, есть ли SecurityManager и правильный метод
+            if self.ssl_manager and hasattr(self.ssl_manager, 'create_ssl_context'):
+                # ✅ ИСПРАВЛЕНИЕ: Используем правильный метод SecurityManager с context_type="client"
+                return self.ssl_manager.create_ssl_context(context_type="client")
+            else:
+                # Fallback если SecurityManager недоступен
+                return self._create_client_ssl_context_fallback()
                 
         except Exception as e:
             self.logger.error(f"Failed to create client SSL context: {e}")
